%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%   This help function determine the controller corresponding to
%    the sensitivity given by its denominator polynomial, alpha. 
%
%
function [sysC,numC,denC,sysS] = Alpha2sysC(alpha,K,sysP,PCintegrators,...
    tmp,Creldegree,Cintegrators)

if isct(sysP)
  %
  %   Continuous-time case
  %
  sysS = tf((K * alpha)',alpha',2);
  sysS = d2c(sysS,'tustin');
  [numS,denS] = tfdata(sysS,'v');
else
  %
  %   Discrete-time case
  %
  sysS = tf((K * alpha)',alpha',sysP.Ts);
end

% 
%   Enforce "s^(PCintegrators)"-factor in the numerator of S
%
if isct(sysS)
  [numS,denS] = tfdata(sysS,'v');
  numS(end-PCintegrators+1:end) = zeros(1,PCintegrators); 
  sysS = tf(numS,denS);
end

%
%   C = (1-S)/(PS)
%
sysTtmp = 1-sysS;
[numTtmp,denTtmp,Ts] = tfdata(sysTtmp,'v');
while abs(numTtmp(1)) < 1e-6
    numTtmp(1) = [];
end
sysTtmp = tf(numTtmp,denTtmp,Ts);
sysC = sysTtmp/sysP/sysS;

%  I am not sure if this step is still necessary. Ryozo May 14, 2004
%       %
%       %   Enforce the relative degree on the numerator of C
%       %      
%       [numC,denC,sysP.Ts] = tfdata(sysC,'v');
%       denC = denC/numC(1);
%       numC = numC/numC(1);
%       while abs(denC(1)) < 1e-9
% 	denC = denC(2:end);
%       end
%       numC = numC(end-length(denC)+1+Creldegree:end);
%       sysC = tf(numC,denC,sysP.Ts);

%
%   Enforce the degree on the denominator of C
%
Cdegree = length(pole(sysP))-1+length(tmp.fixpoint)+Creldegree+Cintegrators;
sysC = MinrealFixDegree(sysC,Cdegree);
[numC,denC] = tfdata(sysC);
sysS = minreal(feedback(1,sysP*sysC));