%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%   Uses the Bounded Real Lemma and LMI to determine 
%    whether a discrete-time transfer function 
%    S(z)=z'Ka/z'a is modulus less than gamma.
%       
%       flag = 1 : ||S||_infty < gamma
%       flag = 0 : ||S||_infty >= gamma
%
function flag = IsBoundedReal(K,a,gamma);

% for test
% a = [1 .5];
% K = [1 0;1 1/4];
% gamma = 1.42;

a = a(:);
[A,B,C,D] = tf2ss((K*a)',a');
n = size(A,1);

%
%   LMI
%
setlmis([])
P = lmivar(1,[n,1]);
lmiterm([1,1,1,P],-1,1)       % -P
lmiterm([1,1,2,P],A,-1)     % -AP
lmiterm([1,1,3,0],-B)       % -B
lmiterm([1,2,2,P],-1,1)       % -P
lmiterm([1,2,4,P],-1,C')    % -PC'
lmiterm([1,3,3,0],-1)       % -I
lmiterm([1,3,4,0],-D')      % -D'
lmiterm([1,4,4,0],-gamma^2)   % -gammaI
lmisys = getlmis;

%
%   Feasibility test
%
options(5) = 1; % no display
[tmin,xfeas] = feasp(lmisys,options);

if tmin < 0
    flag = 1;
else
    flag = 0;
end