%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%   Uses the inverse Levinson algorithm to determine 
%    whether a polynomial is Schur (stable).
%
function flag = IsSchurnorm(a);

flag = 1;
a = [ 1 a(:)' ];
n = length(a)-1;
alpha(n+1,:) = a;

for l = n:-1:1
  K(l) = -alpha(l+1,l+1);
  if abs(K(l)) >= 1
     flag = 0;
     return
  end
  alpha(l,2:l) = (alpha(l+1,2:l)+K(l)*fliplr(alpha(l+1,2:l)))/(1-K(l)^2);
end
