%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%
%   This is a help function to the nonlinear least-squares approach
%    to shaping the sensitivity function. The point is assumed to
%    be feasible.
%
function [F,Jac] = NLSsensitivityred(...
    schurpoly,Sdesired,zvec,weightvec,zvecmat)

%
%   An ugly global variable that consists of the current estimate
%
global NLSparameters

%
%   Compute actual Schurpoly
%
schurpoly = conv([1 schurpoly],NLSparameters.r);

%
%   Compute the interpolant
%
disspoly = GetDissPoly(schurpoly);
parameters.disspoly = disspoly;
parameters.alpha0 = NLSparameters.gIK*NLSparameters.alpha0;
parameters.disspoly0 = NLSparameters.disspoly0;
parameters.K = NLSparameters.Khat;
[alphahat] = homotopy(parameters,0);
alpha = NLSparameters.gIKinv * alphahat;
beta = NLSparameters.K * alpha;

%
%   Update the global variable
%
NLSparameters.alpha0 = alpha;
NLSparameters.disspoly0 = disspoly;

%
%   Compute the functional value
%
F = (polyval(beta,zvec)./polyval(alpha,zvec) - Sdesired)...
    .* weightvec;
F = [ real(F); imag(F) ];

if nargout > 1
  
  %
  %   Determine the Jacobian of the residual vector
  %
  dhda = NLSparameters.gIKinv;
  dadd = inv(GetJacobian(alphahat,NLSparameters.Khat));
  dddrho = GetS(schurpoly);
  zvecmata = zvecmat*alpha;
  zvecmatbaa = zvecmat*beta ./ zvecmata ./ zvecmata;
  dFdrho = ((zvecmat * NLSparameters.K )...
	    ./ zvecmata(:,ones(1,length(disspoly))) ...
	    - zvecmat...
	    .* zvecmatbaa(:,ones(1,length(disspoly))))...
	   * dhda * dadd * dddrho...
	   .* weightvec(:,ones(1,length(schurpoly)));
  Jac = [ real(dFdrho); imag(dFdrho) ] * NLSparameters.T;
  Jac = Jac(:,2:end);
end