%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%   This function computes the order of the senasitivity function
%    in the complexity constrained sensitivity shaping problem. 
%
%
function order = OrderCount(sysP,Creldegree,Cintegrators,xfreq)

ustpoles = pole(sysP);
nmpzeros = zero(sysP);
reldegree = length(ustpoles)-length(nmpzeros);
if isct(sysP)
  order = length(find(real([ustpoles; nmpzeros]) >= 0));
  added = length(xfreq) + length(find(xfreq > 1e-3 & xfreq < 1e3));
else
  order = length(find(abs([ustpoles; nmpzeros]) >= 1));
  added = length(xfreq) + ...
	  length(find(abs(xfreq) > 1e-2 & abs(xfreq - pi) > 1e-2));
end

order = order + reldegree + Creldegree + Cintegrators ...
	+ added - 1;
  