%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
function [Sd] = PlotDesired(...
    Sd,theta,Sdesired,weight,plotparameters,Ts,gamma,xspec)

figure(1), clf

if Ts ~= 0
    theta = theta / Ts;
end

%
%  Magnitude
%
Sd.subplot1 = subplot(3,1,1);
feval(plotparameters.plotvec{2},theta,20*log10(abs(Sdesired)),'kx'), hold on
if any(Sd.Sdesiredmod ~= Sdesired)
  feval(plotparameters.plotvec{2},theta,20*log10(abs(Sd.Sdesiredmod)),'b+');
  tmplegendvec = {'Original' 'Modified'};
else
  tmplegendvec = {'Original'};
end
feval(plotparameters.plotvec{2},theta,20*log10(abs(Sd.Sdesirednew)),'ro')
eval(plotparameters.grid);
feval(plotparameters.plotvec{2},[theta(1) theta(end)],...
      20*log10(gamma)*[1 1],'r-')
if Ts == 0,
    feval(plotparameters.plotvec{2},xspec.freq,xspec.mag,'bo')
else
    feval(plotparameters.plotvec{2},xspec.freq/Ts,xspec.mag,'bo')
end

%
%  Phase
%
Sd.subplot2 = subplot(3,1,2);
feval(plotparameters.plotvec{2},theta,180/pi*angle(Sdesired),'kx'), hold on
if any(Sd.Sdesiredmod ~= Sdesired)
  feval(plotparameters.plotvec{2},theta,180/pi*angle(Sd.Sdesiredmod),'b+')
end
feval(plotparameters.plotvec{2},theta,180/pi*angle(Sd.Sdesirednew),'ro')
legend({ tmplegendvec{1:end} 'New'})
eval(plotparameters.grid);
if Ts == 0,
    feval(plotparameters.plotvec{2},xspec.freq,xspec.phase,'bo')
else
    feval(plotparameters.plotvec{2},xspec.freq/Ts,xspec.phase,'bo')
end

%
%  Weight
%
Sd.subplot3 = subplot(3,1,3);
feval(plotparameters.plotvec{1},theta,weight,'kx'), hold on
if any(Sd.weightmod ~= weight)
  feval(plotparameters.plotvec{1},theta,Sd.weightmod,'b+')
  tmplegendvec = {'Original' 'Modified'};
else
  tmplegendvec = {'Original'};
end
feval(plotparameters.plotvec{1},theta,Sd.weightnew,'ro')
legend({ tmplegendvec{1:end} 'New'})
eval(plotparameters.grid);