%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%   This is a help funciton to Sshaper for plotting Bode plots,
%    step responses etc.
%
function [] = PlotFunction(type,sys,titlestr,parameters,theta,Sdesired)

if length(sys) == 1
  parameters.legendvec = parameters.legendvec(1);
end

switch type
 case 'bode'
  W = 10.^(linspace(log10(parameters.lower),log10(parameters.upper),500));
  for k = 1:length(sys)
    if isdt(sys{1})
      theta = theta/sys{1}.Ts;
    end      
    [mag,phase,W] = bode(sys{k},W); 
    subplot(2,1,1)
    feval(parameters.plotvec{2},...
	  W,20*log10(squeeze(mag)),... 
	  parameters.linestylevec{k}), hold on
    subplot(2,1,2)
    feval(parameters.plotvec{2},...
	  W,squeeze(phase),... 
	  parameters.linestylevec{k}), hold on
  end
  subplot(2,1,1)
  ylabel('Magnitude (dB)')
  eval(parameters.grid);
  axisvec = axis;
  if isdt(sys{k})
    axis([theta(1) theta(end) axisvec(3:4)]);
  else
    axis([parameters.lower parameters.upper axisvec(3:4)]);
  end    
  subplot(2,1,2)
  ylabel('Phase (deg)')
  xlabel('Frequency (rad/sec)')
  eval(parameters.grid);
  axisvec = axis;
  if isdt(sys{k})
    axis([theta(1) theta(end) axisvec(3:4)]);
  else
    axis([parameters.lower parameters.upper axisvec(3:4)]);
  end  
  legend(parameters.legendvec)
  subplot(2,1,1)        
  
 case 'step'
  for k = 1:length(sys)
    if isempty(parameters.T)
      step(sys{k},parameters.linestylevec{k}), hold on
    else
      step(sys{k},parameters.linestylevec{k},parameters.T), hold on
    end
  end
  legend(parameters.legendvec,4)
  eval(parameters.grid);
 case 'sensitivity'
  %%% Ryozo modified here. June 3, 2004
  W = 10.^(linspace(log10(parameters.lower),log10(parameters.upper),500));     
  for k = 1:length(sys)
    if isdt(sys{1})
      theta = theta/sys{1}.Ts;
    end      
    [mag,phase,W] = bode(sys{k},W); 
    subplot(2,1,1)
    feval(parameters.plotvec{2},...
	  W,20*log10(squeeze(mag)),... 
	  parameters.linestylevec{k}), hold on
    subplot(2,1,2)
    feval(parameters.plotvec{2},...
	  W,squeeze(phase),... 
	  parameters.linestylevec{k}), hold on
  end
  subplot(2,1,1)
  feval(parameters.plotvec{2},...
	theta,20*log10(abs(Sdesired)),...
	parameters.markerstyle)
  ylabel('Magnitude (dB)')
  eval(parameters.grid);
  axisvec = axis;
  if isdt(sys{k})
    axis([theta(1) theta(end) axisvec(3:4)]);
  else
    axis([parameters.lower parameters.upper axisvec(3:4)]);
  end    
  subplot(2,1,2)
  feval(parameters.plotvec{2},...
	theta,angle(Sdesired)*180/pi,...
	parameters.markerstyle)
  legend({parameters.legendvec{1:end} 'Desired'})
  ylabel('Phase (deg)')
  xlabel('Frequency (rad/sec)')
  eval(parameters.grid);
  axisvec = axis;
  if isdt(sys{k})
    axis([theta(1) theta(end) axisvec(3:4)]);
  else
    axis([parameters.lower parameters.upper axisvec(3:4)]);
  end  
  %  axis([parameters.lower parameters.upper axisvec(3:4)]);
  subplot(2,1,1)
end

title(titlestr)
ChangeTextStyle(gcf,parameters.myfontsize,...
		parameters.myfontweight,...
		parameters.mylinewidth);