%
%   This file is a help function of "Sshaper" developed by Anders
%    Blomqvist and Ryozo Nagamune. The theory behind the program is
%    presented in the technical report
%
%     "Sensitivity shaping with degree constraint by nonlinear
%     least-squares optimization"
%
%    (TRITA-MAT xxxxx, KTH, Stockholm, Sweden) and references
%    therin. Any questions can be sent to andersb@math.kth.se
%    and/or ryozo@me.berkeley.edu.
%
%   This function plots the desired sensitivity and the weight
%   making them available for interactive use.
%
function Sd = PlotInteractive(...
    theta,Sdesired,weight,plotparameters,Ts,gamma,xspec)

if Ts ~= 0
    theta = theta/Ts; % (rad/sec)
end

figure(1), clf
Sd.subplot1 = subplot(3,1,1); 
feval(plotparameters.plotvec{2},theta,20*log10(abs(Sdesired)),...
      plotparameters.markerstyle)
title('Bode plot of desired sensitivity')
ylabel('Magnitude (dB)')
eval(plotparameters.grid);
hold on
if not(isempty(theta))
  feval(plotparameters.plotvec{2},[theta(1) theta(end)],...
	20*log10(gamma)*[1 1],'r-')
end
if Ts == 0,
    feval(plotparameters.plotvec{2},xspec.freq,xspec.mag,'bo')
else
    feval(plotparameters.plotvec{2},xspec.freq/Ts,xspec.mag,'bo')
end

Sd.subplot2 = subplot(3,1,2); 
feval(plotparameters.plotvec{2},theta,180/pi*angle(Sdesired),...
      plotparameters.markerstyle)
ylabel('Phase (deg)')
eval(plotparameters.grid);
hold on
if Ts == 0,
    feval(plotparameters.plotvec{2},xspec.freq,xspec.phase,'bo')
else
    feval(plotparameters.plotvec{2},xspec.freq/Ts,xspec.phase,'bo')
end

Sd.subplot3 = subplot(3,1,3); 
if length(weight) ~= length(theta)
  weight = ones(size(theta));
end
feval(plotparameters.plotvec{1},theta,weight,plotparameters.markerstyle)
title('Weight')
ylabel('Magnitude')
xlabel('Frequency (rad/sec)')
eval(plotparameters.grid);
hold on
ChangeTextStyle(gcf,plotparameters.myfontsize,...
		plotparameters.myfontweight,...
		plotparameters.mylinewidth);
