%
%   This function comstructs a block-toeplitz matrix.
%
%   Input: c(:,:,k) = ck, k = 1..nc
%          r(:,:,k) = rk, k = 1..nr
%                  [ ri11 ... ri1p ]
%             ri = [  .         .  ]
%                  [ riq1 ... riqp ]
%
%           Note: c & r can be of either row or column block stucture
%
%               [ c0 r1 ... rnr   ] 
%   Output: t = [ c1 c0 ... rnr-1 ]
%               [  .  .      .    ]
%               [ cnc   ...  c0   ]
%
function t = BlkToeplitz(c,r)

if nargin < 2
    r = BlkTrans(c);
end

[ qc pc nc ] = size(c);
[ qr pr nr ] = size(r);

if qr ~= qc | pr ~= pc
    error('In BlkToeplitz: different dimiensions')
    return
end

if norm(c(:,:,1)-r(:,:,1)) > 1e-6*norm(c(:,:,1))
    error('In BlkToeplitz: diagonal conflict')
    return
end

x = [];
for k = 1:nr
    x = [ r(:,:,k); x ];
end
for k = 2:nc
    x = [ x; c(:,:,k) ];
end

cidx = (1:qc*nc)';
ridx = [];
for k = (nr-1):-1:0
    ridx = [ ridx k*qr:size(x,1):(prod(size(x))-1) ];
end

t = cidx(:,ones(pr*nr,1)) + ridx(ones(qc*nc,1),:);
t(:) = x(t);