function [a,flag] = wilson_fix(q,k);
%wilson_fix Uses Wilsons algorithm for spectral factorization (with a fix)
%
% Uses Wilsons Newton algorithm to compute the spectral 
% factorization a of the quasi polynomial q , and Vostrys
% method to solve the equation system for the Newton step.
%
%  a= a0 z^n + a1 z^(n-1) + ... + an.
%
%  q= q1 + q2 (z+z^(-1))/2 + q3 (z^2+z^(-2))/2 +...+ qn(z^(n-1)+z^(1-n))/2
%
% With a fix for unstable solutions ...

%
%   Flag is one if sucessful
%
flag = 1;

n=length(q); 
c=[q(1) q(2:n)/2];
theta=[sqrt(q(1)) q(2:n)/2/sqrt(q(1))]; 
c_act=ones(1,n);

iter=0;
while max(abs(c_act-c)) > k & iter < 100;
  iter=iter+1;
  p=zeros(1,n-1);
  p(1)=-theta(n)/theta(1);
  phi=zeros(n-1);
  phi(1,:)=theta(1:n-1)+p(1)*fliplr(theta(2:n));
  
  for i=2:n-1
    p(i)=-phi(i-1,n-1)/phi(i-1,i-1);
    phi(i,i:n-1)=phi(i-1,i-1:n-2)+p(i)*fliplr(phi(i-1,i:n-1));
  end
  
  if max(abs(p)) > 1       % Stability check !
    q_roots=sort(roots([q(n:-1:2)/2 q(1) q(2:n)/2]));    
    a=poly(q_roots(1:n-1)*.99999); a=real(a*sqrt(q(n)/(2*a(n)*a(1))));
    %    disp('unstable solution in Wilson routine')
    flag = 0;
    return
  end
  
  % F_T=toeplitz([theta(1) zeros(1,n-1)],theta); c_act=(F_T*theta')'  
  quasi_pol=conv(theta,fliplr(theta));
  c_act=quasi_pol(n:2*n-1);
  cc=c+c_act;
  
  y=zeros(1,n);  
  y(1)=cc(1)/2/phi(n-1,n-1);
  y(n)=cc(n)/phi(1,1);  
  
  for i=1:n-2
    y(n-i)=(cc(n-i)-y(n+1-i:n)*phi(i:-1:1,i+1))/phi(i+1,i+1);
  end

  for i=1:n-1
    y(1:i+1)=y(1:i+1)+p(n-i)*fliplr(y(1:i+1));
  end
  theta=y;
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % The procedure above is a smart way to do ...  %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
  %                                               %
  % F_T=toeplitz([theta(1) zeros(1,n-1)],theta);  %
  % F_H=hankel(theta,[theta(n) zeros(1,n-1)]);    %
  % F=(F_T+F_H);                                  %
  % c_act=(F_T*theta')';                          %
  % theta = (F\(c'+c_act') )'                     %
  %                                               %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end
a=theta;