%
%   This is a help function for homotopy.m and is devised to 
%    find a step length h such that the predictor step stays 
%    within the region given by
%
%     (1-mu) tao_0 < <S_alpha(K(alpha)),1> < (1+mu) tao_0 
%
function h = FindStepSize(alpha,dalpha,K,mu)

%
%   Determine second order equation coefficients
%
a = dalpha'*K*dalpha;
b = - dalpha'*K*alpha - alpha'*K*dalpha;
c = alpha'*K*alpha;

p = b/a;
q = mu*c/a;

if p > 0
    h = -p/2+sqrt(p^2/4+abs(q));
elseif p^2/4 > abs(q)
    h = -p/2-sqrt(p^2/4-abs(q));
else
    h = -p/2+sqrt(p^2/4+abs(q));
end

