%
%   This function determines the matrix that connects the
%    coefficients of the denominator and numerator polynomials
%    respectively. The linear relations comes from fulfilling 
%    the interpolation constraints:
%
%       l! f^(l)(z_k) = w_kl
%
%                beta0 +  beta1 z + ... +  betan z^n
%       f(z) = --------------------------------------
%               alpha0 + alpha1 z + ... + alphan z^n
%
%   Then 
%
%   [ beta0 ]                    [ alpha0 ]
%   [ beta1 ]                    [ alpha1 ]
%   [   :   ] = Gamma^-1 W Gamma [   :    ]
%   [ betan ]                    [ alphan ]
%
%
function K = GetK(interdata)

%
%   Construct matrices
%
W = []; A = []; B = [];
for k = 1:interdata.ntilde
    vec = interdata.Wvec{k};
%    W = blkdiag(W,abs(pascal(length(vec),1)) ...
%        .*toeplitz(vec,[vec(1) zeros(1,length(vec)-1)]));  % Modified by anders 030403
    W = blkdiag(W,toeplitz(vec,[vec(1) zeros(1,length(vec)-1)]));
    A = blkdiag(A,diag(interdata.z(k)*ones(size(vec))) ...
        + diag(ones(length(vec)-1,1),-1));
    B = [ B; 1; zeros(length(vec)-1,1) ];
end

Gamma = ctrb(A,B);

%
%   Compute K
%
K = real(Gamma \ W * Gamma);
